@@ -35,6 +35,7 @@ has data => (
                 name  => '<<YOUR NAME HERE>>',
                 email => '<<YOUR EMAIL ADDRESS HERE>>',
             },
+            namespace => [],
         };
         $config->merge_data($data, $config->user_data);
         return $data;
@@ -80,6 +81,16 @@ has config_file => (
     },
 );
 
+has distconfig_file => (
+    is       => 'rw',
+    isa      => 'Str',
+    lazy     => 1,
+    default  => sub {
+        my($config) = @_;
+        return '.dimconfig';
+    },
+);
+
 sub path {
     my($config, $basename) = @_;
     return File::Spec->catfile(
@@ -175,12 +186,18 @@ sub save_data {
         chmod 0700, $home or warn "Cannot chmod $home: $!";
     }
 
-    my $header = "# This file is managed by $0.\n";
+    my $header = "#!perl\n" . "# This file is managed by $0.\n";
     $config->save( $file => $header . $config->dump_data($data) )
         or die "Cannot save config file";
     chmod 0600, $file;
 }
 
+sub save_data_to_distconfig {
+    my($config, $distdir, $data) = @_;
+
+    $config->save_data( "$distdir/" . $config->distconfig_file, $data);
+}
+
 
 no Mouse;
 __PACKAGE__->meta->make_immutable();
